==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PointSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeries, _super);
    function PointSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PointSeries.$;
        return _this;
    }
    PointSeries.prototype.get_c1 = function () {
        return true;
    };
    PointSeries.prototype.bv = function () {
        return new PointSeriesView(this);
    };
    PointSeries.prototype.lo = function (a) {
        _super.prototype.lo.call(this, a);
        this.uo = a;
    };
    PointSeries.prototype.gl = function () {
        return 0.7;
    };
    PointSeries.prototype.pu = function () {
        if (this.pt == 0) {
            return 2;
        }
        return _super.prototype.pu.call(this);
    };
    PointSeries.prototype.er = function (a, b) {
        var c = this.pb(this.pe(a), true, false);
        if (this.p3(a, b)) {
            return true;
        }
        return false;
    };
    PointSeries.prototype.lt = function (a, b, c, d) {
        _super.prototype.lt.call(this, a, b, c, d);
    };
    Object.defineProperty(PointSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.r7;
        },
        enumerable: false,
        configurable: true
    });
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
}(HorizontalAnchoredCategorySeries));
export { PointSeries };
/**
 * @hidden
 */
var PointSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeriesView, _super);
    function PointSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.da = a;
        return _this;
    }
    PointSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.p0 = Defaults.e;
        }
    };
    PointSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.o0 = a;
        this.e.gm = 3;
        this.e.gn = 2;
        this.e.go = 2;
        this.e.e3 = false;
    };
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
}(AnchoredCategorySeriesView));
export { PointSeriesView };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PointSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeries, _super);
    function PointSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PointSeries.$;
        return _this;
    }
    PointSeries.prototype.get_c4 = function () {
        return true;
    };
    PointSeries.prototype.bx = function () {
        return new PointSeriesView(this);
    };
    PointSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.u7 = a;
    };
    PointSeries.prototype.gv = function () {
        return 0.7;
    };
    PointSeries.prototype.p7 = function () {
        if (this.p6 == 0) {
            return 2;
        }
        return _super.prototype.p7.call(this);
    };
    PointSeries.prototype.ev = function (a, b) {
        var c = this.pm(this.pp(a), true, false);
        if (this.qg(a, b)) {
            return true;
        }
        return false;
    };
    PointSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
    };
    Object.defineProperty(PointSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.sk;
        },
        enumerable: false,
        configurable: true
    });
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
}(HorizontalAnchoredCategorySeries));
export { PointSeries };
/**
 * @hidden
 */
var PointSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeriesView, _super);
    function PointSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.da = a;
        return _this;
    }
    PointSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.qd = Defaults.e;
        }
    };
    PointSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 3;
        this.e.gx = 2;
        this.e.gy = 2;
        this.e.e7 = false;
    };
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
}(AnchoredCategorySeriesView));
export { PointSeriesView };
